@@ -3,9 +3,10 @@
 from collections import Counter
 import random
 
+import matplotlib.pyplot as plt
 import numpy as np
 
-from axelrod import DEFAULT_TURNS, Player
+from axelrod import DEFAULT_TURNS, Player, Game
 from .deterministic_cache import DeterministicCache
 from .graph import complete_graph, Graph
 from .match import Match
@@ -39,6 +40,7 @@ def fitness_proportionate_selection(scores: List) -> int:
 class MoranProcess(object):
     def __init__(self, players: List[Player], turns: int = DEFAULT_TURNS,
                  prob_end: float = None, noise: float = 0,
+                 game: Game = None,
                  deterministic_cache: DeterministicCache = None,
                  mutation_rate: float = 0., mode: str = 'bd',
                  interaction_graph: Graph = None,
@@ -93,6 +95,7 @@ class MoranProcess(object):
         """
         self.turns = turns
         self.prob_end = prob_end
+        self.game = game
         self.noise = noise
         self.initial_players = players  # save initial population
         self.players = []  # type: List
@@ -321,6 +324,7 @@ class MoranProcess(object):
             match = Match((player1, player2),
                           turns=self.turns, prob_end=self.prob_end,
                           noise=self.noise,
+                          game=self.game,
                           deterministic_cache=self.deterministic_cache)
             match.play()
             match_scores = match.final_score_per_turn()
@@ -385,6 +389,43 @@ class MoranProcess(object):
         """
         return len(self.populations)
 
+    def populations_plot(self, ax=None):
+        """
+        Create a stackplot of the population distributions at each iteration of
+        the Moran process.
+
+        Parameters
+        ----------------
+        ax: matplotlib axis
+            Allows the plot to be written to a given matplotlib axis.
+            Default is None.
+
+        Returns
+        -----------
+        A matplotlib axis object
+
+        """
+        player_names = self.populations[0].keys()
+        if ax is None:
+            _, ax = plt.subplots()
+        else:
+            ax = ax
+
+        plot_data = []
+        labels = []
+        for name in player_names:
+            labels.append(name)
+            values = [counter[name] for counter in self.populations]
+            plot_data.append(values)
+            domain = range(len(values))
+
+        ax.stackplot(domain, plot_data, labels=labels)
+        ax.set_title("Moran Process Population by Iteration")
+        ax.set_xlabel("Iteration")
+        ax.set_ylabel("Number of Individuals")
+        ax.legend()
+        return ax
+
 
 class ApproximateMoranProcess(MoranProcess):
     """
