@@ -7,9 +7,14 @@ from .averagecopier import AverageCopier, NiceAverageCopier
 from .axelrod_first import (
     Davis, RevisedDowning, Feld, Grofman, Nydegger, Joss, Shubik, Tullock,
     UnnamedStrategy, SteinAndRapoport, TidemanAndChieruzzi)
-from .axelrod_second import Champion, Eatherley, Tester, Gladstein, Tranquilizer, MoreGrofman
+from .axelrod_second import (
+    Champion, Eatherley, Tester, Gladstein, Tranquilizer, MoreGrofman,
+    Kluepfel, Borufsen, Cave, WmAdams, GraaskampKatzen, Weiner, Harrington,
+    MoreTidemanAndChieruzzi, Getzler, Leyvraz, White, Black, RichardHufford,
+    Yamachi, Colbert)
 from .backstabber import BackStabber, DoubleCrosser
 from .better_and_better import BetterAndBetter
+from .bush_mosteller import BushMosteller
 from .calculator import Calculator
 from .cooperator import Cooperator, TrickyCooperator
 from .cycler import (
@@ -76,7 +81,8 @@ from .titfortat import (
     TitForTat, TitFor2Tats, TwoTitsForTat, Bully, SneakyTitForTat,
     SuspiciousTitForTat, AntiTitForTat, HardTitForTat, HardTitFor2Tats,
     OmegaTFT, Gradual, ContriteTitForTat, AdaptiveTitForTat,
-    SpitefulTitForTat, SlowTitForTwoTats2, Alexei, EugineNier, DynamicTwoTitsForTat, NTitsForMTats, Michaelos)
+    SpitefulTitForTat, SlowTitForTwoTats2, Alexei, EugineNier,
+    DynamicTwoTitsForTat, NTitsForMTats, Michaelos, RandomTitForTat)
 from .verybad import VeryBad
 from .worse_and_worse import (WorseAndWorse, KnowledgeableWorseAndWorse,
                               WorseAndWorse2, WorseAndWorse3)
@@ -102,12 +108,17 @@ all_strategies = [
     Appeaser,
     ArrogantQLearner,
     AverageCopier,
-    BetterAndBetter,
     BackStabber,
+    BetterAndBetter,
+    Black,
+    Borufsen,
     Bully,
+    BushMosteller,
     Calculator,
     CautiousQLearner,
+    Cave,
     Champion,
+    Colbert,
     CollectiveStrategy,
     ContriteTitForTat,
     Cooperator,
@@ -156,6 +167,7 @@ all_strategies = [
     GellerCooperator,
     GellerDefector,
     GeneralSoftGrudger,
+    Getzler,
     Gladstein,
     GoByMajority,
     GoByMajority10,
@@ -163,6 +175,7 @@ all_strategies = [
     GoByMajority40,
     GoByMajority5,
     Golden,
+    GraaskampKatzen,
     Gradual,
     GradualKiller,
     Grofman,
@@ -178,13 +191,16 @@ all_strategies = [
     HardProber,
     HardTitFor2Tats,
     HardTitForTat,
+    Harrington,
     HesitantQLearner,
     Hopeless,
     Inverse,
     InversePunisher,
     Joss,
+    Kluepfel,
     KnowledgeableWorseAndWorse,
     LevelPunisher,
+    Leyvraz,
     LimitedRetaliate,
     LimitedRetaliate2,
     LimitedRetaliate3,
@@ -198,6 +214,7 @@ all_strategies = [
     MindWarper,
     MirrorMindReader,
     MoreGrofman,
+    MoreTidemanAndChieruzzi,
     Negation,
     NiceAverageCopier,
     NTitsForMTats,
@@ -221,12 +238,14 @@ all_strategies = [
     Raider,
     Random,
     RandomHunter,
+    RandomTitForTat,
     RemorsefulProber,
     Resurrection,
     Retaliate,
     Retaliate2,
     Retaliate3,
     RevisedDowning,
+    RichardHufford,
     Ripoff,
     RiskyQLearner,
     SelfSteem,
@@ -260,14 +279,18 @@ all_strategies = [
     Tullock,
     TwoTitsForTat,
     VeryBad,
+    Weiner,
+    White,
     Willing,
     Winner12,
     Winner21,
     WinShiftLoseStay,
     WinStayLoseShift,
+    WmAdams,
     WorseAndWorse,
     WorseAndWorse2,
     WorseAndWorse3,
+    Yamachi,
     ZDExtortion,
     ZDExtort2,
     ZDExtort3,
