@@ -114,7 +114,7 @@ class DynamicTwoTitsForTat(Player):
 
     name = 'Dynamic Two Tits For Tat'
     classifier = {
-        'memory_depth': 2,  # Long memory, memory-2
+        'memory_depth': float("inf"),
         'stochastic': True,
         'makes_use_of': set(),
         'long_run_time': False,
@@ -127,7 +127,7 @@ class DynamicTwoTitsForTat(Player):
     def strategy(opponent):
         # First move
         if not opponent.history:
-            # Make sure we cooporate first turn
+            # Make sure we cooperate first turn
             return C
         if D in opponent.history[-2:]:
             # Probability of cooperating regardless
@@ -790,3 +790,55 @@ class Michaelos(Player):
                 return D
 
         return opponent.history[-1]
+
+
+class RandomTitForTat(Player):
+    """
+    A player starts by cooperating and then follows by copying its
+    opponent (tit for tat style).  From then on the player
+    will switch between copying its opponent and randomly
+    responding every other iteration.
+
+    Name:
+
+    - Random TitForTat: Original name by Zachary M. Taylor
+    """
+
+    # These are various properties for the strategy
+    name = 'Random Tit for Tat'
+    classifier = {
+        'memory_depth': 1,
+        'stochastic': True,
+        'makes_use_of': set(),
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+
+    def __init__(self, p: float=0.5) -> None:
+        """
+        Parameters
+        ----------
+        p, float
+            The probability to cooperate
+        """
+        super().__init__()
+        self.p = p
+        self.act_random = False
+        if p in [0, 1]:
+            self.classifier['stochastic'] = False
+
+
+    def strategy(self, opponent: Player) -> Action:
+        """This is the actual strategy"""
+        if not self.history:
+            return C
+
+        if self.act_random:
+            self.act_random = False
+            return random_choice(self.p)
+
+        self.act_random = True
+        return opponent.history[-1]
